// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
// Module: Specgroup
// Author: Richard Saxton 
//
// Description: Main class for calculating  a source fluxer profile
//
// Modifications: See ChangeLog
//

#ifndef Specgroup_H
#define Specgroup_H

/* General classes */
#include <iostream>
#include "WishInterpreter.h"

/* SAS-specific classes */
#include "Tracer.h"
#include "Dal.h"

/* Local Structure */

/*
struct Response {
	vector<vector<float> > matrix;
	vector<double> elo,
		       ehi,
		       eblo,
		       ebhi;
};
*/

/****************************************************
 *
 * class Specgroup
 *
 ***************************************************/

class Specgroup
{
public:

  /* Constructor */
  Specgroup();

  /* Destructor */
  ~Specgroup();

  /* Member fields */
  /* Methods */
  //Response fixrmf( string &rmfname ) const;
    
    /* Purpose:
		To read in the RMF and set the matrix 
       Input:
		rmfname - name of the input response matrix file
    */

  void writeGroups(Table *spectrumtable, vector<WishInterpreter::Group> groups);

    /* Purpose:
                To copy grouping structure into output file
       Input:
                spectrumtable - pointer to output table
                groups - vector of grouping information
    */

  void writeQuality(Table *spectrumtable, vector<short int> inQual);

    /* Purpose:
                To write quality array into output file
       Input:
                spectrumtable - pointer to output table
                inQual - vector of quality information
    */

  void writeAssociated(Table *spectrumtable);

    /* Purpose:
                To write associated filenames into output header
       Input:
                spectrumtable - pointer to output table
    */
 
  double getBackscale(Table *spectrumtable);

    /* Purpose:
                To find the BACKSCAL value from either a header keyword 
		or a column of energy-dependent backscale values.
       Input:
                spectrumtable - pointer to output table
    */


  private:

   // Define a structure to hold the spectral information
/*
    struct Spectrum {
        string srcfile;   // Name of the input spectrum
        vector<int> channels;
        vector<int> counts;
        vector<int> bcounts;
        double areanorm;

      // Conversion from PI chans to spectral channel
        bool gotPIconv = true;
        int specdelt, specpix, specval;
    };
  */
    //Spectrum srcspec;

};

#endif

